@@ -8,7 +8,7 @@ from percept.utils.models import FieldModel
 
 from percept.fields.base import Dict
 from percept.conf.base import settings
-from percept.utils.models import RegistryCategories
+from percept.utils.models import RegistryCategories, get_namespace
 from percept.utils.input import DataFormats
 from percept.tests.framework import JSONFormatTester
 import os
@@ -16,6 +16,13 @@ import re
 import logging
 log = logging.getLogger(__name__)
 
+def is_number(n):
+    try:
+        n.astype(float)
+        return True
+    except ValueError:
+        return False
+
 class BaseFormat(FieldModel):
     """
     Base class to reformat input data.  If implementing, add in from_ and to_ methods (see read_input and get_data)
@@ -25,7 +32,7 @@ class BaseFormat(FieldModel):
 
     #Set the category and namespace for the registry
     category = RegistryCategories.formatters
-    namespace = settings.NAMESPACE
+    namespace = get_namespace(__module__)
 
     help_text = "Base class for reformatting input data.  Do not use directly."
 
@@ -107,8 +114,9 @@ class JSONFormat(BaseFormat):
                 key_list.append(self.data[i][k])
             column_list.append(key_list)
         df = DataFrame(np.asarray(column_list).transpose(), columns=keys)
-        for i in xrange(0,df.shape[0]):
-            df.iloc[i] = df.iloc[i].astype(float)
+        for i in xrange(0,df.shape[1]):
+            if is_number(df.iloc[:,i]):
+                df.iloc[:,i] = df.iloc[:,i].astype(float)
         return df
 
 
