@@ -16,11 +16,10 @@ import logging
 
 log = logging.getLogger(__name__)
 
-class SVMTrain(Task):
+class Train(Task):
     """
     A class to train a support vector machine algorithm
     """
-    colnames = List()
     clf = Complex()
     category = RegistryCategories.algorithms
     algorithm = svm.SVC
@@ -36,16 +35,13 @@ class SVMTrain(Task):
     help_text = "Example class to train and predict with SVM."
 
     def train(self, data, target, **kwargs):
-        self.colnames = [t for t in data.columns]
-
-        C = kwargs.get('C',1)
-
         #When doing self.clf =clf , __set__ is called on the field.
         # But, when doing self.clf = self.algorithm() and self.clf.fit(), __set__ is not called.
         # Work around this by doing the fit logic on a local variable, and then assigning to self.clf,
-        clf = self.algorithm(C=C)
-        clf.fit(data, target)
+        clf = self.algorithm(**kwargs)
+        clf = clf.fit(data, target)
         self.clf = clf
+        return self.clf
 
     def predict(self, test_data, **kwargs):
         test_data = test_data
