@@ -4,7 +4,6 @@ Testing framework
 
 import logging
 log = logging.getLogger(__name__)
-from percept.utils.registry import registry, find_in_registry
 from percept.utils.models import RegistryCategories, find_needed_formatter, find_needed_input
 import numpy as np
 
@@ -53,7 +52,7 @@ class CSVInputTester(Tester):
 
     def test(self, **kwargs):
         super(CSVInputTester, self).test(**kwargs)
-        stream = open(kwargs.get('stream'))
+        stream = kwargs.get('stream')
         inst = self.cls()
         inst.read_input(stream)
         assert isinstance(inst.data, list)
@@ -63,9 +62,10 @@ class JSONFormatTester(Tester):
 
     def test(self, **kwargs):
         super(JSONFormatTester, self).test(**kwargs)
-        stream = open(kwargs.get('stream'))
+        stream = kwargs.get('stream')
         dataformat = kwargs.get('dataformat')
         inst = self.cls()
+        from percept.utils.registry import registry, find_in_registry
         selected_registry = find_in_registry(category = RegistryCategories.inputs)
         selected_input_registry = [i for i in selected_registry if i.input_format==dataformat]
         if len(selected_input_registry)>0:
@@ -81,7 +81,7 @@ class NormalizationTester(Tester):
 
     def test(self, **kwargs):
         super(NormalizationTester, self).test(**kwargs)
-        stream = open(kwargs.get('stream'))
+        stream = kwargs.get('stream')
         dataformat = kwargs.get('dataformat')
         inst = self.cls()
         output_format = inst.data_format
@@ -101,8 +101,8 @@ class SVMTester(Tester):
 
     def test(self, **kwargs):
         super(SVMTester, self).test(**kwargs)
-        datafile = open(kwargs.get('data'))
-        targetfile = open(kwargs.get('target'))
+        datafile = kwargs.get('data')
+        targetfile = kwargs.get('target')
         dataformat = kwargs.get('dataformat')
 
         inst = self.cls()
