@@ -10,6 +10,9 @@ import inspect
 
 log = logging.getLogger(__name__)
 
+def get_namespace(mod):
+    return mod.split('.')[0]
+
 def get_task_name(obj):
     try:
         name = "{0}.{1}.{2}".format(obj.category, obj.namespace, obj.name)
@@ -101,7 +104,7 @@ class FieldModel(object):
     """
     __metaclass__ = MetaFieldModel
     category = RegistryCategories.base
-    namespace = settings.NAMESPACE
+    namespace = get_namespace(__module__)
     name = __name__.lower()
 
     def __init__(self, **kwargs):
@@ -125,6 +128,22 @@ class FieldModel(object):
                 if member_object.required_input:
                     self.required_input.append(member_name)
 
+    def __getstate__(self):
+        self_dict = self.__dict__
+        for field in self.fields:
+            self_dict.update(
+                {
+                    field : getattr(self, field),
+                }
+            )
+        return self_dict
+
+    def __setstate__(self, state):
+        self.__dict__ = state
+        for field in self.fields:
+            setattr(self, field, getattr(self.__class__, field))
+            setattr(self, field, state[field])
+
     def get_data(self):
         data_dict = {}
         for key in self.fields:
